All Classes and Interfaces
Class
Description
Created by oliver on 18/11/16.
Created by oliver.oldfieldhodge on 13/4/17.
Created by oliver on 18/11/16.
Created by oliver on 6/06/2016.
Created by oliver on 25/5/17.
Created by oliver.oldfieldhodge on 3/1/17.
The events client posts events back to featureflow.
Created by oliver on 6/06/2016.
Created by oliver on 6/06/2016.
Event source handler based on netty implementation here:
https://github.com/michaelklishin/eventsource-netty5/blob/master/src/main/java/io/opensensors/sse/client/impl/EventStreamParser.java
Created by oliver on 6/06/2016.
This is used to actively register available features in the featureflowClient
A feature can declare its key and available variants
If the feature does not exist in featureflow then it will be created with the defined variants
If no variants are defined then a default on/off feature will be created
If a feature does match then the variants will be merged and the feature will be shown as available in the clients configured environment
A feature control hold the configuration for a feature for a given environment.
This is the repository that will hold the runtime state for features
Created by oliver on 7/06/2016.
Created by oliver on 26/05/2016.
Created by oliver on 23/05/2016.
Updated to use HttpClient 5.x
Created by oliver on 23/05/2016.
User provider to provide featureflow with a user and attributes
Implement the user provider to provide featureflow is a user and attributes
Updated to use standard Java concurrency APIs instead of HttpClient-specific ones
Created by oliver on 26/05/2016.
Updated to use HttpClient 5.x
A Rule holds and Audience (Who to show to) and a list of VariantSplits (what to show them)
Simple in Map implementation for local feature caching
Created by oliver on 26/05/2016.
Created by oliver on 18/11/16.