Class FeatureflowClient

java.lang.Object
io.featureflow.client.FeatureflowClient
All Implemented Interfaces:
Closeable, AutoCloseable

public class FeatureflowClient extends Object implements Closeable
Created by oliver on 23/05/2016. The featureflow client is the interface to clients using featureflow. The client uses the SSE Stream, Rest Client and Repository to manage features Configuration may be provided to register feature controls and capabilities Callbacks may be assigned to proved on-demand updates to feature control changes