Uses of Class
io.featureflow.client.FeatureflowUser
Packages that use FeatureflowUser
-
Uses of FeatureflowUser in io.featureflow.client
Methods in io.featureflow.client that return FeatureflowUserModifier and TypeMethodDescriptionFeatureflowUserProvider.getUser()FeatureflowUser.saveUser(boolean save) Whether we should persist this context information to assist in lookup laterFeatureflowUser.setAttributes(Map<String, com.google.gson.JsonElement> attributes) FeatureflowUser.setSessionAttributes(Map<String, com.google.gson.JsonElement> sessionAttributes) FeatureflowUser.withAttribute(String key, boolean value) FeatureflowUser.withAttribute(String key, Number value) FeatureflowUser.withAttribute(String key, String value) FeatureflowUser.withAttribute(String key, org.joda.time.DateTime value) FeatureflowUser.withAttributes(Map<String, com.google.gson.JsonElement> values) FeatureflowUser.withBucketKey(String bucketKey) The bucket key is used specifically for percentage rollouts, it is the key by default however you may wish to set it specifically to handle a consistent experience if the key varies (such as a user logging in)FeatureflowUser.withDateAttributes(String key, List<org.joda.time.DateTime> values) FeatureflowUser.withNumberAttributes(String key, List<Number> values) FeatureflowUser.withSessionAttribute(String key, Number value) FeatureflowUser.withSessionAttribute(String key, String value) FeatureflowUser.withSessionAttribute(String key, org.joda.time.DateTime value) FeatureflowUser.withSessionAttributes(Map<String, com.google.gson.JsonElement> values) FeatureflowUser.withSessionDateAttributes(String key, List<org.joda.time.DateTime> values) FeatureflowUser.withSessionNumberAttributes(String key, List<Number> values) FeatureflowUser.withSessionStringAttributes(String key, List<String> values) FeatureflowUser.withStringAttributes(String key, List<String> values) Methods in io.featureflow.client with parameters of type FeatureflowUserModifier and TypeMethodDescriptionFeatureflowClient.evaluate(String featureKey, FeatureflowUser user) Evaluate with a specific user, this will override any userProvider or anonymous userFeatureflowClient.evaluateAll(FeatureflowUser user) voidFeatureflowClient.track(String goalKey, FeatureflowUser user) -
Uses of FeatureflowUser in io.featureflow.client.model
Methods in io.featureflow.client.model with parameters of type FeatureflowUserModifier and TypeMethodDescriptionFeatureControl.evaluate(FeatureflowUser user) booleanAudience.matches(FeatureflowUser user) booleanCondition.matches(FeatureflowUser user) booleanRule.matches(FeatureflowUser user) Constructors in io.featureflow.client.model with parameters of type FeatureflowUser