Enum Class CallbackEvent

java.lang.Object
java.lang.Enum<CallbackEvent>
io.featureflow.client.core.CallbackEvent
All Implemented Interfaces:
Serializable, Comparable<CallbackEvent>, Constable

public enum CallbackEvent extends Enum<CallbackEvent>
Created by oliver.oldfieldhodge on 13/4/17.
  • Enum Constant Details

  • Method Details

    • values

      public static CallbackEvent[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static CallbackEvent valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null