Class RestClientImpl

java.lang.Object
io.featureflow.client.core.RestClientImpl
All Implemented Interfaces:
RestClient

public class RestClientImpl extends Object implements RestClient
Updated to use HttpClient 5.x
  • Constructor Details

  • Method Details

    • registerFeatureControls

      public void registerFeatureControls(List<Feature> featureRegistrations) throws IOException
      Register any code defined feature controls as available and retrieve a list of features form the server
      Specified by:
      registerFeatureControls in interface RestClient
      Parameters:
      featureRegistrations - list of features to register
      Throws:
      IOException - cannot connect to register
    • postEvents

      public void postEvents(List<? extends Event> events)
      Specified by:
      postEvents in interface RestClient