Class PollingClientExample

java.lang.Object
io.featureflow.client.example.PollingClientExample

public class PollingClientExample extends Object
Example demonstrating the FeatureflowPollingClient with callbacks. This demo runs for 60 seconds to show polling behavior and feature update callbacks. The polling client is now the default behavior unless streaming is explicitly enabled.
  • Constructor Details

    • PollingClientExample

      public PollingClientExample()
  • Method Details

    • main

      public static void main(String[] args)