Enum Class Operator

java.lang.Object
java.lang.Enum<Operator>
io.featureflow.client.model.Operator
All Implemented Interfaces:
Serializable, Comparable<Operator>, Constable

public enum Operator extends Enum<Operator>
Created by oliver on 26/05/2016.
  • Enum Constant Details

    • equals

      public static final Operator equals
    • testRuleEquals

      public static final Operator testRuleEquals
    • lessThan

      public static final Operator lessThan
    • greaterThan

      public static final Operator greaterThan
    • greaterThanOrEqual

      public static final Operator greaterThanOrEqual
    • lessThanOrEqual

      public static final Operator lessThanOrEqual
    • startsWith

      public static final Operator startsWith
    • endsWith

      public static final Operator endsWith
    • matches

      public static final Operator matches
    • in

      public static final Operator in
    • notIn

      public static final Operator notIn
    • contains

      public static final Operator contains
    • before

      public static final Operator before
    • after

      public static final Operator after
  • Method Details

    • values

      public static Operator[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static Operator valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • evaluate

      public abstract boolean evaluate(com.google.gson.JsonPrimitive contextValue, List<com.google.gson.JsonPrimitive> targetValues)
    • getDateTime

      protected static org.joda.time.DateTime getDateTime(com.google.gson.JsonPrimitive date)