Class Variant

java.lang.Object
io.featureflow.client.model.Variant

public class Variant extends Object
Created by oliver on 26/05/2016. A variant is a variant of a feature and at its simplest is ON or OFF but can be any combination of values rad,blue,green,big,small etc A variant is targeted at an Audience then equally split based on its variant split and a equally distributed generated Hash value