Class FeatureflowClient
java.lang.Object
io.featureflow.client.FeatureflowClient
- All Implemented Interfaces:
Closeable,AutoCloseable
Created by oliver on 23/05/2016.
The featureflow client is the interface to clients using featureflow.
The client uses the SSE Stream, Rest Client and Repository to manage features
Configuration may be provided to register feature controls and capabilities
Callbacks may be assigned to proved on-demand updates to feature control changes
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classclass -
Method Summary
Modifier and TypeMethodDescriptionstatic FeatureflowClient.Buildervoidclose()evaluate(String featureKey, FeatureflowUser user) Evaluate with a specific user, this will override any userProvider or anonymous userevaluateAll(FeatureflowUser user) voidtrack(String goalKey, FeatureflowUser user)
-
Method Details
-
evaluate
Evaluate with a specific user, this will override any userProvider or anonymous user- Parameters:
featureKey-user-- Returns:
-
evaluate
-
evaluate
-
evaluateAll
-
close
- Specified by:
closein interfaceAutoCloseable- Specified by:
closein interfaceCloseable- Throws:
IOException
-
builder
-
track
-