Package io.featureflow.client.core
Class RestClientImpl
java.lang.Object
io.featureflow.client.core.RestClientImpl
- All Implemented Interfaces:
RestClient
Updated to use HttpClient 5.x
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoidpostEvents(List<? extends Event> events) voidregisterFeatureControls(List<Feature> featureRegistrations) Register any code defined feature controls as available and retrieve a list of features form the server
-
Constructor Details
-
RestClientImpl
-
-
Method Details
-
registerFeatureControls
Register any code defined feature controls as available and retrieve a list of features form the server- Specified by:
registerFeatureControlsin interfaceRestClient- Parameters:
featureRegistrations- list of features to register- Throws:
IOException- cannot connect to register
-
postEvents
- Specified by:
postEventsin interfaceRestClient
-