Package io.featureflow.client.example
Class PollingClientExample
java.lang.Object
io.featureflow.client.example.PollingClientExample
Example demonstrating the FeatureflowPollingClient with callbacks.
This demo runs for 60 seconds to show polling behavior and feature update callbacks.
The polling client is now the default behavior unless streaming is explicitly enabled.
-
Constructor Summary
Constructors -
Method Summary
-
Constructor Details
-
PollingClientExample
public PollingClientExample()
-
-
Method Details
-
main
-