Package io.featureflow.client.model
Class Feature
java.lang.Object
io.featureflow.client.model.Feature
This is used to actively register available features in the featureflowClient
A feature can declare its key and available variants
If the feature does not exist in featureflow then it will be created with the defined variants
If no variants are defined then a default on/off feature will be created
If a feature does match then the variants will be merged and the feature will be shown as available in the clients configured environment
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
variants
-
key
-
failoverVariant
-
-
Constructor Details
-
Feature
-
Feature
-
Feature
-
Feature
-