Class FeatureControl
java.lang.Object
io.featureflow.client.model.FeatureControl
A feature control hold the configuration for a feature for a given environment.
A feature control is matched by evaluating a List of type Rule
A Rule contains an
Audience and a List of io.featureflow.client.model.VariantSplit - for a given audience we apply the given splits
A VariantSplit defines which variant is shown to a proportion of users. If a rule is for one Variant only then the split will be 100% for that variant.
An Audience is a list of Conditions containing a Target - Operator - Value*
A seed value is used to generate the split and is set on the feature control. This can be changed to redistribute the splits.-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
key
-
salt
-
enabled
public boolean enabled -
deleted
public boolean deleted -
rules
-
offVariantKey
-
inClientApi
public boolean inClientApi
-
-
Constructor Details
-
FeatureControl
public FeatureControl()
-
-
Method Details
-
getKey
-
evaluate
-
toString
-