Package io.featureflow.client.model
Class Variant
java.lang.Object
io.featureflow.client.model.Variant
Created by oliver on 26/05/2016.
A variant is a variant of a feature and at its simplest is ON or OFF but can be any combination of values rad,blue,green,big,small etc
A variant is targeted at an Audience then equally split based on its variant split and a equally distributed generated Hash value
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
-
Field Details
-
off
- See Also:
-
on
- See Also:
-
key
-
name
-
-
Constructor Details
-
Variant
public Variant() -
Variant
-